@@ -37,7 +37,7 @@ def nps(data, time_win=5, time_step=5, sub_opt=0):
 
     Returns
     -------
-    NPS : array
+    nps : array
         The EEG-like NPS.
         If sub_opt=0, the shape of NPS is [n_chls, int((n_ts-time_win)/time_step)+1, 2].
         If sub_opt=1, the shape of NPS is [n_subs, n_chls, int((n_ts-time_win)/time_step)+1, 2].
@@ -62,8 +62,8 @@ def nps(data, time_win=5, time_step=5, sub_opt=0):
             for i in range(nchls):
                 for j in range(ts):
 
-                    data1 = data[0, sub, :, i, j*time_win:j*time_win+time_win]
-                    data2 = data[1, sub, :, i, j*time_win:j*time_win+time_win]
+                    data1 = data[0, sub, :, i, j*time_step:j*time_step+time_win]
+                    data2 = data[1, sub, :, i, j*time_step:j*time_step+time_win]
                     data1 = np.reshape(data1, [ntrials*time_win])
                     data2 = np.reshape(data2, [ntrials*time_win])
                     # calculate the Pearson Coefficient
@@ -82,8 +82,8 @@ def nps(data, time_win=5, time_step=5, sub_opt=0):
     for i in range(nchls):
         for j in range(ts):
 
-            data1 = avgdata[0, i, j*time_win:j*time_win+time_win]
-            data2 = avgdata[1, i, j*time_win:j*time_win+time_win]
+            data1 = avgdata[0, i, j*time_step:j*time_step+time_win]
+            data2 = avgdata[1, i, j*time_step:j*time_step+time_win]
             # calculate the Pearson Coefficient
             nps[i, j] = pearsonr(data1, data2)
 
@@ -111,10 +111,14 @@ def nps_fmri(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1]):
 
     Returns
     -------
-    subNPS : array
+    nps : array
         The fMRI NPS for searchlight.
         The shape of NPS is [n_subs, n_x, n_y, n_z, 2]. n_subs, n_x, n_y, n_z represent the number of subjects, the
-        number of calculation units for searchlight along the x, y, z axis.
+        number of calculation units for searchlight along the x, y, z axis. 2 represent a r-value and a p-value.
+
+    Notes
+    -----
+    The size of the calculation units should at least be [3, 3, 3].
     """
 
     # get the number of subjects and the size of the fMRI-img
@@ -201,6 +205,10 @@ def nps_fmri_roi(fmri_data, mask_data):
     subNPS : array
         The fMRI NPS for ROI.
         The shape of NPS is [n_subs, 2]. n_subs represents the number of subjects. 2 represents a r-value and a p-value.
+
+    Notes
+    -----
+    The size of the calculation units should at least be [3, 3, 3].
     """
 
     # get the number of subjects and the size of the fMRI-img
